@@ -81,7 +81,7 @@ class CustomOption(Option):
 
 def getparser() -> OptionParser:
     parser = OptionParser(
-        option_class=CustomOption, version=__version__.public(),
+        option_class=CustomOption, version=__version__,
         usage="usage: %prog [options] SOURCEPATH...")
     parser.add_option(
         '-c', '--config', dest='configfile',
@@ -92,7 +92,16 @@ def getparser() -> OptionParser:
         help=("A dotted name of the class to use to make a system."))
     parser.add_option(
         '--project-name', dest='projectname',
-        help=("The project name, appears in the html."))
+        help=("The project name, shown at the top of each HTML page."))
+    parser.add_option(
+        '--project-version',
+        dest='projectversion',
+        default='',
+        metavar='VERSION',
+        help=(
+            "The version of the project for which the API docs are generated. "
+            "Defaults to empty string."
+            ))
     parser.add_option(
         '--project-url', dest='projecturl',
         help=("The project url, appears in the html if given."))
@@ -134,9 +143,6 @@ def getparser() -> OptionParser:
         '--html-summary-pages', dest='htmlsummarypages',
         action='store_true', default=False,
         help=("Only generate the summary pages."))
-    parser.add_option(
-        '--html-write-function-pages', dest='htmlfunctionpages',
-        default=False, action='store_true', help=SUPPRESS_HELP)
     parser.add_option(
         '--html-output', dest='htmloutput', default='apidocs',
         help=("Directory to save HTML files to (default 'apidocs')"))
@@ -251,16 +257,16 @@ def parse_args(args: Sequence[str]) -> Tuple[Values, List[str]]:
     parser = getparser()
     options, args = parser.parse_args(args)
     options.verbosity -= options.quietness
+
+    _warn_deprecated_options(options)
+
     return options, args
 
-def main(args: Sequence[str] = sys.argv[1:]) -> int:
-    options, args = parse_args(args)
-
-    exitcode = 0
-
-    if options.configfile:
-        readConfigFile(options)
 
+def _warn_deprecated_options(options: Values) -> None:
+    """
+    Check the CLI options and warn on deprecated options.
+    """
     if options.enable_intersphinx_cache_deprecated:
         print("The --enable-intersphinx-cache option is deprecated; "
               "the cache is now enabled by default.",
@@ -273,11 +279,22 @@ def main(args: Sequence[str] = sys.argv[1:]) -> int:
         print("The --add-package option is deprecated; "
               "pass packages as positional arguments instead.",
               file=sys.stderr, flush=True)
-    if options.htmlfunctionpages:
-        print("The --html-write-function-pages option is deprecated; "
-              "use the generated Intersphinx inventory (objects.inv) "
-              "for deep-linking your documentation.",
-              file=sys.stderr, flush=True)
+
+
+
+
+def main(args: Sequence[str] = sys.argv[1:]) -> int:
+    """
+    This is the console_scripts entry point for pydoctor CLI.
+
+    @param args: Command line arguments to run the CLI.
+    """
+    options, args = parse_args(args)
+
+    exitcode = 0
+
+    if options.configfile:
+        readConfigFile(options)
 
     cache = prepareCache(clearCache=options.clear_intersphinx_cache,
                          enableCache=options.enable_intersphinx_cache,
@@ -404,7 +421,7 @@ def main(args: Sequence[str] = sys.argv[1:]) -> int:
             else:
                 writer.writeModuleIndex(system)
                 subjects = system.rootobjects
-            writer.writeIndividualFiles(subjects, options.htmlfunctionpages)
+            writer.writeIndividualFiles(subjects)
             if system.docstring_syntax_errors:
                 def p(msg: str) -> None:
                     system.msg('docstring-summary', msg, thresh=-1, topthresh=1)
@@ -425,6 +442,7 @@ def main(args: Sequence[str] = sys.argv[1:]) -> int:
             sphinx_inventory = SphinxInventoryWriter(
                 logger=system.msg,
                 project_name=system.projectname,
+                project_version=system.options.projectversion,
                 )
             if not os.path.exists(options.htmloutput):
                 os.makedirs(options.htmloutput)
