@@ -1,8 +1,6 @@
 """Render pydoctor data as HTML."""
 
-from __future__ import print_function
-
-DOCTYPE = '''\
+DOCTYPE = b'''\
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
           "DTD/xhtml1-strict.dtd">
